==> mapsemble-1.0.0.tar.gz: mapsemble/src/Entity/MapsembleMap.php <==
<?php

declare(strict_types=1);

namespace Drupal\mapsemble\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Entity\Attribute\ConfigEntityType;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\mapsemble\MapsembleMapInterface;

/**
 * Defines the Mapsemble map configuration entity class.
 */
#[ConfigEntityType(
  id: 'mapsemble_map',
  label: new TranslatableMarkup('Mapsemble map'),
  config_prefix: 'mapsemble_map',
  entity_keys: [
    'id' => 'id',
    'label' => 'label',
  ],
  handlers: [
    'list_builder' => 'Drupal\mapsemble\MapsembleMapListBuilder',
    'form' => [
      'add' => 'Drupal\mapsemble\Form\MapsembleMapForm',
      'edit' => 'Drupal\mapsemble\Form\MapsembleMapForm',
      'delete' => 'Drupal\Core\Entity\EntityDeleteForm',
    ],
  ],
  links: [
    'collection' => '/admin/structure/mapsemble-map',
    'add-form' => '/admin/structure/mapsemble-map/add',
    'edit-form' => '/admin/structure/mapsemble-map/{mapsemble_map}',
    'configure-form' => '/admin/structure/mapsemble-map/{mapsemble_map}/configure',
    'delete-form' => '/admin/structure/mapsemble-map/{mapsemble_map}/delete',
  ],
  admin_permission: 'administer mapsemble',
  config_export: [
    'id',
    'label',
    'mapId',
    'layerId',
    'dataSourceId',
    'config',
  ],
)]
final class MapsembleMap extends ConfigEntityBase implements MapsembleMapInterface {

  /**
   * The map ID.
   *
   * @var string
   */
  protected string $id = '';

  /**
   * The map label.
   *
   * @var string
   */
  protected string $label = '';

  /**
   * The map ID.
   *
   * @var string
   */
  protected string $mapId = '';

  /**
   * The layer ID.
   *
   * @var string
   */
  protected string $layerId = '';

  /**
   * The data source ID.
   *
   * @var string
   */
  protected string $dataSourceId = '';

  /**
   * The map configuration.
   *
   * @var array
   */
  protected array $config = [];

  /**
   * Get the configuration for the map.
   *
   * @return array
   *   The map configuration.
   */
  public function getConfig(): array {
    return $this->config;
  }

}

==> mapsemble-1.0.2.tar.gz: mapsemble/src/Entity/MapsembleMap.php <==
<?php

declare(strict_types=1);

namespace Drupal\mapsemble\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Entity\Attribute\ConfigEntityType;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\mapsemble\MapsembleMapInterface;

/**
 * Defines the Mapsemble map configuration entity class.
 */
#[ConfigEntityType(
  id: 'mapsemble_map',
  label: new TranslatableMarkup('Mapsemble map'),
  config_prefix: 'map',
  entity_keys: [
    'id' => 'name',
    'label' => 'label',
  ],
  handlers: [
    'list_builder' => 'Drupal\mapsemble\MapsembleMapListBuilder',
    'form' => [
      'add' => 'Drupal\mapsemble\Form\MapsembleMapForm',
      'edit' => 'Drupal\mapsemble\Form\MapsembleMapForm',
      'delete' => 'Drupal\Core\Entity\EntityDeleteForm',
    ],
  ],
  links: [
    'collection' => '/admin/structure/mapsemble-map',
    'add-form' => '/admin/structure/mapsemble-map/add',
    'edit-form' => '/admin/structure/mapsemble-map/{mapsemble_map}',
    'configure-form' => '/admin/structure/mapsemble-map/{mapsemble_map}/configure',
    'delete-form' => '/admin/structure/mapsemble-map/{mapsemble_map}/delete',
  ],
  admin_permission: 'administer mapsemble',
  constraints: [
    'ImmutableProperties' => [
      'name',
    ],
  ],
  config_export: [
    'name',
    'label',
    'mapId',
    'layerId',
    'dataSourceId',
    'settings',
  ],
)]
final class MapsembleMap extends ConfigEntityBase implements MapsembleMapInterface {

  /**
   * The map ID.
   *
   * @var string
   */
  protected string $name = '';

  /**
   * The map label.
   *
   * @var string
   */
  protected string $label = '';

  /**
   * The map ID.
   *
   * @var string
   */
  protected string $mapId = '';

  /**
   * The layer ID.
   *
   * @var string
   */
  protected string $layerId = '';

  /**
   * The data source ID.
   *
   * @var string
   */
  protected string $dataSourceId = '';

  /**
   * The map configuration.
   *
   * @var array
   */
  protected array $settings = [];

  /**
   * Get the configuration for the map.
   *
   * @return array
   *   The map configuration.
   */
  public function getSettings(): array {
    return $this->settings;
  }

  /**
   * {@inheritdoc}
   */
  public function id() {
    return $this->name;
  }

}
